# Mind Foundry OPTaaS Python Client

[![pypi-version](https://img.shields.io/pypi/v/mindfoundry-optaas-client.svg)](https://pypi.python.org/pypi/mindfoundry-optaas-client)
[![license](https://img.shields.io/pypi/l/mindfoundry-optaas-client.svg)](https://pypi.python.org/pypi/mindfoundry-optaas-client)
[![docs-sphinx](https://img.shields.io/badge/docs-sphinx-green.svg)](https://demo.optimize.mindfoundry.ai/static/client_docs/index.html)
[![tutorials-binder](https://img.shields.io/badge/tutorials-binder-ff69b4.svg)](https://tutorial.optaas.mindfoundry.ai)

[OPTaaS](https://mindfoundry.ai/optaas) (Optimization as a Service) is a general-purpose Bayesian optimizer developed
by [Mind Foundry](https://mindfoundry.ai) which provides optimal hyper-parameter configurations via web-services.
It can handle any parameter type and does not need to know the underlying process, models, or data.

This Python client makes it easier to interact with the web service and integrate with other Python libraries such as
[scikit-learn](http://scikit-learn.org).
